#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 09/06/2001
#################################################################################
#
# Guest - Script part of Webchat designed to lead guests to rooms
# Copyright (C) 2000-2001  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204 - 817, 5th Street NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Param;						# Parameter control
use Ethereal::Post;						# Post handler
use Ethereal::Table;						# Table handler
use Ethereal::Who;						# Who is on


#################################################################################
# Data Members
#################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $param;							# Parameter handle

#################################################################################
# Program Area
#################################################################################

	# Initial parameters
	$cgi      = new CGI;	
	$database = new Ethereal::Database();	
	$param    = new Ethereal::Param();

	# Connect and fetch
	$database->Connect();
	$param->GetParam($cgi);

	# Document header
	print $cgi->header();

	# Flush standard output
	$| = 1;
	print "";


	# If undefined list realms, puppets and links
	if (defined($param->{'READONLY'}))
	{ 
		RealmDisplay($database, $cgi, $param); 
	}

	# Otherwise entrance
	elsif (defined($param->{'ENTRANCE'}))
	{ 
		Entrance($database, $cgi, $param); 
	}

	# Realm selection
	else
	{ 
		RealmSelect($database, $cgi, $param); 
	}


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Entrance
#
# The entrace simply lists all people in a room, and the rooms information.  This
# is no different then normal applications

sub Entrance
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list

	my $info;						# Room information
	my $who;						# Who handle

	#####################
	# Program area

	# Cleanup
	$param->Cleanup('ENTRANCE');


	# Display HTML
	# Display header
	$database->DocumentGetHeader();

	# Retreive realm information
	($info) = $database->DataGetRealmDescription($param->{'ROOM'});

	# Wrap with tables
	if (defined($info))
	{
		# Wrap with tables
		print "<TABLE WIDTH=\"100%\">\n\t<TR>\n\t\t<TD VALIGN=\"top\">";

		# Retreive realm information
		$who = new Ethereal::Who($database, $cgi, $param);
		$who->WhoGuest();

		# Mid section and info
		print "\n\t\t</TD>\n\t\t<TD VALIGN=\"top\">";
		print "$info\n";

		# Hind quarter
		print "\n\t\t</TD>\n\t</TR>\n</TABLE>";
        }

	# HTML footer
	$database->DocumentGetFooter();
}

#####################
# Realm Display
#
# Will create a single pane window for use, expressly to be able to view what is
# happening inside the realm.  This differs considerably from normal use. 

sub RealmDisplay						# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list

	my $post;						# Post handle


	#####################
	# Program area

	# Assign a user
	$param->{'USER'} = 'Guest';
	$param->{'CHAR'} = 'Guest';

	# Display HTML
	# Display header
	$database->DocumentGetHeaderPlain();

	# Simply show streaming
	$post = new Ethereal::Post();
	$post->HandleStream($database, $cgi, $param);

	# HTML footer
	print $cgi->end_html();
}

#####################
# Realm Selections
#
# Allows the guest to select a public realm that allows gues access.  This is
# as to allow harser rooms to may be public but do not want the peering eyes
# of guests to see.

sub RealmSelect							# Database, CGI, Parameter list
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list

	my $inline;						# Inline parameter handling
	my $realms;						# Formatted list of realms
	my $table;						# Table handle	

	my @realms;						# List of realms

	my %portal;						# Portal hash


	#####################
	# Program area

	# Link to hash
	$database->GetHashPortal(\%portal);
	
	# Retreive and format values for Realms
	$database->GetListGuestRealms(\@realms);	
	$realms  = $cgi->scrolling_list('ROOM', \@realms, $realms[0], 10);


	# Display HTML and Title
	$database->DocumentGetHeader();
	print "$portal{'TagTitle'}\n<BR>\n";

	# Create inline link
	$inline = $param->EmbedInline($cgi, %{$param});

	# Start form
	print $cgi->start_form();
	print $param->EmbedNormal($cgi, %{$param}, 'ENTRANCE', 'true'), "\n";

	# Table handle
	$table = new Ethereal::Table($cgi);

	# Realm Section
	$table->MakeTop();
	$table->MakeSingle($portal{'TagSecRealm'});
	$table->MakeSingle("<A HREF=\"$portal{LnkGlobalWho}$inline\" TARGET=\"_TOP\">$portal{TagLnkGlobalWho}</A>");
	$table->MakeBlank();

	$table->MakeValid($portal{'TagSelectRealm'},   $realms);
	$table->MakeBlank();
	
	$table->MakeValid($cgi->submit($portal{'TxtSubmitRealms'}), $cgi->reset($portal{'TxtResetRealms'}));
	$table->MakeBottom();

	# End from
	print $cgi->end_form(), "\n";

	# HTML footer
	$database->DocumentGetFooter();
}
